@@ -216,24 +216,14 @@ test('fromNow', function (assert) {
 });
 
 test('calendar day', function (assert) {
-    var a = moment().hours(2).minutes(0).seconds(0);
+    var a = moment().hours(12).minutes(0).seconds(0);
 
-    assert.equal(moment(a).calendar(), 'ယနေ. ၀၂:၀၀ မှာ', 'ယနေ. ဒီအချိန်');
-    assert.equal(moment(a).add({
-        m: 25
-    }).calendar(), 'ယနေ. ၀၂:၂၅ မှာ', 'ယခုမှ ၂၅ မိနစ်ပေါင်းထည့်');
-    assert.equal(moment(a).add({
-        h: 1
-    }).calendar(), 'ယနေ. ၀၃:၀၀ မှာ', 'ယခုမှ ၁ နာရီပေါင်းထည့်');
-    assert.equal(moment(a).add({
-        d: 1
-    }).calendar(), 'မနက်ဖြန် ၀၂:၀၀ မှာ', 'မနက်ဖြန် ဒီအချိန်');
-    assert.equal(moment(a).subtract({
-        h: 1
-    }).calendar(), 'ယနေ. ၀၁:၀၀ မှာ', 'ယခုမှ ၁ နာရီနှုတ်');
-    assert.equal(moment(a).subtract({
-        d: 1
-    }).calendar(), 'မနေ.က ၀၂:၀၀ မှာ', 'မနေ.က ဒီအချိန်');
+    assert.equal(moment(a).calendar(),                  'ယနေ. ၁၂:၀၀ မှာ',      'ယနေ. ဒီအချိန်');
+    assert.equal(moment(a).add({m: 25}).calendar(),     'ယနေ. ၁၂:၂၅ မှာ',      'ယခုမှ ၂၅ မိနစ်ပေါင်းထည့်');
+    assert.equal(moment(a).add({h: 1}).calendar(),      'ယနေ. ၁၃:၀၀ မှာ',      'ယခုမှ ၁ နာရီပေါင်းထည့်');
+    assert.equal(moment(a).add({d: 1}).calendar(),      'မနက်ဖြန် ၁၂:၀၀ မှာ',  'မနက်ဖြန် ဒီအချိန်');
+    assert.equal(moment(a).subtract({h: 1}).calendar(), 'ယနေ. ၁၁:၀၀ မှာ',      'ယခုမှ ၁ နာရီနှုတ်');
+    assert.equal(moment(a).subtract({d: 1}).calendar(), 'မနေ.က ၁၂:၀၀ မှာ',     'မနေ.က ဒီအချိန်');
 });
 
 test('calendar next week', function (assert) {
@@ -287,67 +277,6 @@ test('calendar all else', function (assert) {
     assert.equal(weeksFromNow.calendar(), weeksFromNow.format('L'), '၂ ပတ် အတွင်း');
 });
 
-test('weeks year starting sunday', function (assert) {
-    assert.equal(moment([2012, 0, 1]).week(), 52, 'Jan  1 2012 should be week 52');
-    assert.equal(moment([2012, 0, 2]).week(), 1, 'Jan  2 2012 should be week 1');
-    assert.equal(moment([2012, 0, 8]).week(), 1, 'Jan  8 2012 should be week 1');
-    assert.equal(moment([2012, 0, 9]).week(), 2, 'Jan  9 2012 should be week 2');
-    assert.equal(moment([2012, 0, 15]).week(), 2, 'Jan 15 2012 should be week 2');
-});
-
-test('weeks year starting monday', function (assert) {
-    assert.equal(moment([2007, 0, 1]).week(), 1, 'Jan  1 2007 should be week 1');
-    assert.equal(moment([2007, 0, 7]).week(), 1, 'Jan  7 2007 should be week 1');
-    assert.equal(moment([2007, 0, 8]).week(), 2, 'Jan  8 2007 should be week 2');
-    assert.equal(moment([2007, 0, 14]).week(), 2, 'Jan 14 2007 should be week 2');
-    assert.equal(moment([2007, 0, 15]).week(), 3, 'Jan 15 2007 should be week 3');
-});
-
-test('weeks year starting tuesday', function (assert) {
-    assert.equal(moment([2007, 11, 31]).week(), 1, 'Dec 31 2007 should be week 1');
-    assert.equal(moment([2008, 0, 1]).week(), 1, 'Jan  1 2008 should be week 1');
-    assert.equal(moment([2008, 0, 6]).week(), 1, 'Jan  6 2008 should be week 1');
-    assert.equal(moment([2008, 0, 7]).week(), 2, 'Jan  7 2008 should be week 2');
-    assert.equal(moment([2008, 0, 13]).week(), 2, 'Jan 13 2008 should be week 2');
-    assert.equal(moment([2008, 0, 14]).week(), 3, 'Jan 14 2008 should be week 3');
-});
-
-test('weeks year starting wednesday', function (assert) {
-    assert.equal(moment([2002, 11, 30]).week(), 1, 'Dec 30 2002 should be week 1');
-    assert.equal(moment([2003, 0, 1]).week(), 1, 'Jan  1 2003 should be week 1');
-    assert.equal(moment([2003, 0, 5]).week(), 1, 'Jan  5 2003 should be week 1');
-    assert.equal(moment([2003, 0, 6]).week(), 2, 'Jan  6 2003 should be week 2');
-    assert.equal(moment([2003, 0, 12]).week(), 2, 'Jan 12 2003 should be week 2');
-    assert.equal(moment([2003, 0, 13]).week(), 3, 'Jan 13 2003 should be week 3');
-});
-
-test('weeks year starting thursday', function (assert) {
-    assert.equal(moment([2008, 11, 29]).week(), 1, 'Dec 29 2008 should be week 1');
-    assert.equal(moment([2009, 0, 1]).week(), 1, 'Jan  1 2009 should be week 1');
-    assert.equal(moment([2009, 0, 4]).week(), 1, 'Jan  4 2009 should be week 1');
-    assert.equal(moment([2009, 0, 5]).week(), 2, 'Jan  5 2009 should be week 2');
-    assert.equal(moment([2009, 0, 11]).week(), 2, 'Jan 11 2009 should be week 2');
-    assert.equal(moment([2009, 0, 13]).week(), 3, 'Jan 12 2009 should be week 3');
-});
-
-test('weeks year starting friday', function (assert) {
-    assert.equal(moment([2009, 11, 28]).week(), 53, 'Dec 28 2009 should be week 53');
-    assert.equal(moment([2010, 0, 1]).week(), 53, 'Jan  1 2010 should be week 53');
-    assert.equal(moment([2010, 0, 3]).week(), 53, 'Jan  3 2010 should be week 53');
-    assert.equal(moment([2010, 0, 4]).week(), 1, 'Jan  4 2010 should be week 1');
-    assert.equal(moment([2010, 0, 10]).week(), 1, 'Jan 10 2010 should be week 1');
-    assert.equal(moment([2010, 0, 11]).week(), 2, 'Jan 11 2010 should be week 2');
-});
-
-test('weeks year starting saturday', function (assert) {
-    assert.equal(moment([2010, 11, 27]).week(), 52, 'Dec 27 2010 should be week 52');
-    assert.equal(moment([2011, 0, 1]).week(), 52, 'Jan  1 2011 should be week 52');
-    assert.equal(moment([2011, 0, 2]).week(), 52, 'Jan  2 2011 should be week 52');
-    assert.equal(moment([2011, 0, 3]).week(), 1, 'Jan  3 2011 should be week 1');
-    assert.equal(moment([2011, 0, 9]).week(), 1, 'Jan  9 2011 should be week 1');
-    assert.equal(moment([2011, 0, 10]).week(), 2, 'Jan 10 2011 should be week 2');
-});
-
 test('weeks year starting sunday formatted', function (assert) {
     assert.equal(moment([2012, 0, 1]).format('w ww wo'), '၅၂ ၅၂ ၅၂', 'Jan  1 2012 should be week 52');
     assert.equal(moment([2012, 0, 2]).format('w ww wo'), '၁ ၀၁ ၁', 'Jan  2 2012 should be week 1');
@@ -356,38 +285,3 @@ test('weeks year starting sunday formatted', function (assert) {
     assert.equal(moment([2012, 0, 15]).format('w ww wo'), '၂ ၀၂ ၂', 'Jan 15 2012 should be week 2');
 });
 
-test('lenient ordinal parsing', function (assert) {
-    var i, ordinalStr, testMoment;
-    for (i = 1; i <= 31; ++i) {
-        ordinalStr = moment([2014, 0, i]).format('YYYY MM Do');
-        testMoment = moment(ordinalStr, 'YYYY MM Do');
-        assert.equal(testMoment.year(), 2014,
-                'lenient ordinal parsing ' + i + ' year check');
-        assert.equal(testMoment.month(), 0,
-                'lenient ordinal parsing ' + i + ' month check');
-        assert.equal(testMoment.date(), i,
-                'lenient ordinal parsing ' + i + ' date check');
-    }
-});
-
-test('lenient ordinal parsing of number', function (assert) {
-    var i, testMoment;
-    for (i = 1; i <= 31; ++i) {
-        testMoment = moment('2014 01 ' + i, 'YYYY MM Do');
-        assert.equal(testMoment.year(), 2014,
-                'lenient ordinal parsing of number ' + i + ' year check');
-        assert.equal(testMoment.month(), 0,
-                'lenient ordinal parsing of number ' + i + ' month check');
-        assert.equal(testMoment.date(), i,
-                'lenient ordinal parsing of number ' + i + ' date check');
-    }
-});
-
-test('strict ordinal parsing', function (assert) {
-    var i, ordinalStr, testMoment;
-    for (i = 1; i <= 31; ++i) {
-        ordinalStr = moment([2014, 0, i]).format('YYYY MM Do');
-        testMoment = moment(ordinalStr, 'YYYY MM Do', true);
-        assert.ok(testMoment.isValid(), 'strict ordinal parsing ' + i);
-    }
-});
