@@ -1,4 +1,5 @@
 import { module, test } from '../qunit';
+import each from '../helpers/each';
 import moment from '../../moment';
 
 module('format');
@@ -115,6 +116,11 @@ test('default format', function (assert) {
     assert.ok(isoRegex.exec(moment().format()), 'default format (' + moment().format() + ') should match ISO');
 });
 
+test('default UTC format', function (assert) {
+    var isoRegex = /\d{4}.\d\d.\d\dT\d\d.\d\d.\d\dZ/;
+    assert.ok(isoRegex.exec(moment.utc().format()), 'default UTC format (' + moment.utc().format() + ') should match ISO');
+});
+
 test('toJSON', function (assert) {
     var supportsJson = typeof JSON !== 'undefined' && JSON.stringify && JSON.stringify.call,
         date = moment('2012-10-09T21:30:40.678+0100');
@@ -144,6 +150,57 @@ test('toISOString', function (assert) {
     assert.equal(date.toISOString(), '-020123-10-09T20:30:40.678Z', 'ISO8601 format on big negative year');
 });
 
+// See https://nodejs.org/dist/latest/docs/api/util.html#util_custom_inspect_function_on_objects
+test('inspect', function (assert) {
+    function roundtrip(m) {
+        /*jshint evil:true */
+        return (new Function('moment', 'return ' + m.inspect()))(moment);
+    }
+    function testInspect(date, string) {
+        var inspected = date.inspect();
+        assert.equal(inspected, string);
+        assert.ok(date.isSame(roundtrip(date)), 'Tried to parse ' + inspected);
+    }
+
+    testInspect(
+        moment('2012-10-09T20:30:40.678'),
+        'moment("2012-10-09T20:30:40.678")'
+    );
+    testInspect(
+        moment('+020123-10-09T20:30:40.678'),
+        'moment("+020123-10-09T20:30:40.678")'
+    );
+    testInspect(
+        moment.utc('2012-10-09T20:30:40.678'),
+        'moment.utc("2012-10-09T20:30:40.678+00:00")'
+    );
+    testInspect(
+        moment.utc('+020123-10-09T20:30:40.678'),
+        'moment.utc("+020123-10-09T20:30:40.678+00:00")'
+    );
+    testInspect(
+        moment.utc('+020123-10-09T20:30:40.678+01:00'),
+        'moment.utc("+020123-10-09T19:30:40.678+00:00")'
+    );
+    testInspect(
+        moment.parseZone('2016-06-11T17:30:40.678+0430'),
+        'moment.parseZone("2016-06-11T17:30:40.678+04:30")'
+    );
+    testInspect(
+        moment.parseZone('+112016-06-11T17:30:40.678+0430'),
+        'moment.parseZone("+112016-06-11T17:30:40.678+04:30")'
+    );
+
+    assert.equal(
+        moment(new Date('nope')).inspect(),
+        'moment.invalid(/* Invalid Date */)'
+    );
+    assert.equal(
+        moment('blah', 'YYYY').inspect(),
+        'moment.invalid(/* blah */)'
+    );
+});
+
 test('long years', function (assert) {
     assert.equal(moment.utc().year(2).format('YYYYYY'), '+000002', 'small year with YYYYYY');
     assert.equal(moment.utc().year(2012).format('YYYYYY'), '+002012', 'regular year with YYYYYY');
@@ -241,7 +298,7 @@ test('week year formats', function (assert) {
         '405-12-31': '0405-52'
     }, i, isoWeekYear, formatted5, formatted4, formatted2;
 
-    moment.locale('dow:1,doy:4', {week: {dow: 1, doy: 4}});
+    moment.defineLocale('dow:1,doy:4', {week: {dow: 1, doy: 4}});
 
     for (i in cases) {
         isoWeekYear = cases[i].split('-')[0];
@@ -252,6 +309,7 @@ test('week year formats', function (assert) {
         formatted2 = moment(i, 'YYYY-MM-DD').format('gg');
         assert.equal(isoWeekYear.slice(2, 4), formatted2, i + ': gg should be ' + isoWeekYear + ', but ' + formatted2);
     }
+    moment.defineLocale('dow:1,doy:4', null);
 });
 
 test('iso weekday formats', function (assert) {
@@ -265,7 +323,7 @@ test('iso weekday formats', function (assert) {
 });
 
 test('weekday formats', function (assert) {
-    moment.locale('dow: 3,doy: 5', {week: {dow: 3, doy: 5}});
+    moment.defineLocale('dow: 3,doy: 5', {week: {dow: 3, doy: 5}});
     assert.equal(moment([1985, 1,  6]).format('e'), '0', 'Feb  6 1985 is Wednesday -- 0th day');
     assert.equal(moment([2029, 8, 20]).format('e'), '1', 'Sep 20 2029 is Thursday  -- 1st day');
     assert.equal(moment([2013, 3, 26]).format('e'), '2', 'Apr 26 2013 is Friday    -- 2nd day');
@@ -273,6 +331,7 @@ test('weekday formats', function (assert) {
     assert.equal(moment([1970, 0,  4]).format('e'), '4', 'Jan  4 1970 is Sunday    -- 4th day');
     assert.equal(moment([2001, 4, 14]).format('e'), '5', 'May 14 2001 is Monday    -- 5th day');
     assert.equal(moment([2000, 0,  4]).format('e'), '6', 'Jan  4 2000 is Tuesday   -- 6th day');
+    moment.defineLocale('dow: 3,doy: 5', null);
 });
 
 test('toString is just human readable format', function (assert) {
@@ -281,13 +340,13 @@ test('toString is just human readable format', function (assert) {
 });
 
 test('toJSON skips postformat', function (assert) {
-    moment.locale('postformat', {
+    moment.defineLocale('postformat', {
         postformat: function (s) {
             s.replace(/./g, 'X');
         }
     });
     assert.equal(moment.utc([2000, 0, 1]).toJSON(), '2000-01-01T00:00:00.000Z', 'toJSON doesn\'t postformat');
-    moment.locale('postformat', null);
+    moment.defineLocale('postformat', null);
 });
 
 test('calendar day timezone', function (assert) {
@@ -341,54 +400,44 @@ test('quarter ordinal formats', function (assert) {
     assert.equal(moment([2000, 0,  2]).format('Qo [quarter] YYYY'), '1st quarter 2000', 'Jan  2 2000 is 1st quarter');
 });
 
-test('full expanded format is returned from abbreviated formats', function (assert) {
-    function forEach(ar, fn) {
-        if (ar.forEach) {
-            return ar.forEach(fn);
-        } else {
-            // IE8
-            for (var i = 0; i < ar.length; i += 1) {
-                fn(ar[i]);
-            }
-        }
-    }
-    function objectKeys(obj) {
-        if (Object.keys) {
-            return Object.keys(obj);
-        } else {
-            // IE8
-            var res = [], i;
-            for (i in obj) {
-                if (obj.hasOwnProperty(i)) {
-                    res.push(i);
-                }
-            }
-            return res;
-        }
-    }
+// test('full expanded format is returned from abbreviated formats', function (assert) {
+//     function objectKeys(obj) {
+//         if (Object.keys) {
+//             return Object.keys(obj);
+//         } else {
+//             // IE8
+//             var res = [], i;
+//             for (i in obj) {
+//                 if (obj.hasOwnProperty(i)) {
+//                     res.push(i);
+//                 }
+//             }
+//             return res;
+//         }
+//     }
 
-    var locales =
-        'ar-sa ar-tn ar az be bg bn bo br bs ca cs cv cy da de-at de dv el ' +
-        'en-au en-ca en-gb en-ie en-nz eo es et eu fa fi fo fr-ca fr-ch fr fy ' +
-        'gd gl he hi hr hu hy-am id is it ja jv ka kk km ko lb lo lt lv me mk ml ' +
-        'mr ms-my ms my nb ne nl nn pl pt-br pt ro ru se si sk sl sq sr-cyrl ' +
-        'sr sv sw ta te th tl-ph tlh tr tzl tzm-latn tzm uk uz vi zh-cn zh-tw';
+//     var locales =
+//         'ar-sa ar-tn ar az be bg bn bo br bs ca cs cv cy da de-at de dv el ' +
+//         'en-au en-ca en-gb en-ie en-nz eo es et eu fa fi fo fr-ca fr-ch fr fy ' +
+//         'gd gl he hi hr hu hy-am id is it ja jv ka kk km ko lb lo lt lv me mk ml ' +
+//         'mr ms-my ms my nb ne nl nn pl pt-br pt ro ru se si sk sl sq sr-cyrl ' +
+//         'sr sv sw ta te th tl-ph tlh tr tzl tzm-latn tzm uk uz vi zh-cn zh-tw';
 
-    forEach(locales.split(' '), function (locale) {
-        var data, tokens;
-        data = moment().locale(locale).localeData()._longDateFormat;
-        tokens = objectKeys(data);
-        forEach(tokens, function (token) {
-            // Check each format string to make sure it does not contain any
-            // tokens that need to be expanded.
-            forEach(tokens, function (i) {
-                // strip escaped sequences
-                var format = data[i].replace(/(\[[^\]]*\])/g, '');
-                assert.equal(false, !!~format.indexOf(token), 'locale ' + locale + ' contains ' + token + ' in ' + i);
-            });
-        });
-    });
-});
+//     each(locales.split(' '), function (locale) {
+//         var data, tokens;
+//         data = moment().locale(locale).localeData()._longDateFormat;
+//         tokens = objectKeys(data);
+//         each(tokens, function (token) {
+//             // Check each format string to make sure it does not contain any
+//             // tokens that need to be expanded.
+//             each(tokens, function (i) {
+//                 // strip escaped sequences
+//                 var format = data[i].replace(/(\[[^\]]*\])/g, '');
+//                 assert.equal(false, !!~format.indexOf(token), 'locale ' + locale + ' contains ' + token + ' in ' + i);
+//             });
+//         });
+//     });
+// });
 
 test('milliseconds', function (assert) {
     var m = moment('123', 'SSS');
@@ -424,3 +473,22 @@ test('Hmm and Hmmss', function (assert) {
     assert.equal(moment('08:34:56', 'HH:mm:ss').format('Hmmss'), '83456');
     assert.equal(moment('18:34:56', 'HH:mm:ss').format('Hmmss'), '183456');
 });
+
+test('k and kk', function (assert) {
+    assert.equal(moment('01:23:45', 'HH:mm:ss').format('k'), '1');
+    assert.equal(moment('12:34:56', 'HH:mm:ss').format('k'), '12');
+    assert.equal(moment('01:23:45', 'HH:mm:ss').format('kk'), '01');
+    assert.equal(moment('12:34:56', 'HH:mm:ss').format('kk'), '12');
+    assert.equal(moment('00:34:56', 'HH:mm:ss').format('kk'), '24');
+    assert.equal(moment('00:00:00', 'HH:mm:ss').format('kk'), '24');
+});
+
+test('Y token', function (assert) {
+    assert.equal(moment('2010-01-01', 'YYYY-MM-DD', true).format('Y'), '2010', 'format 2010 with Y');
+    assert.equal(moment('-123-01-01', 'Y-MM-DD', true).format('Y'), '-123', 'format -123 with Y');
+    assert.equal(moment('12345-01-01', 'Y-MM-DD', true).format('Y'), '+12345', 'format 12345 with Y');
+    assert.equal(moment('0-01-01', 'Y-MM-DD', true).format('Y'), '0', 'format 0 with Y');
+    assert.equal(moment('1-01-01', 'Y-MM-DD', true).format('Y'), '1', 'format 1 with Y');
+    assert.equal(moment('9999-01-01', 'Y-MM-DD', true).format('Y'), '9999', 'format 9999 with Y');
+    assert.equal(moment('10000-01-01', 'Y-MM-DD', true).format('Y'), '+10000', 'format 10000 with Y');
+});
